<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:optim="http://www.ibm.com/optim/audit/v11.3.0.0"
	xmlns:optimreport="http://www.ibm.com/optim/report/v11.3.0.0"
	xmlns:optimcommon="http://www.ibm.com/optim/common/v11.3.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">

	<xsl:import href="CommonTemplates.xsl"/>
	<xsl:import href="InsertReportTemplates.xsl"/>
	<xsl:output method="html" indent="yes" version="4.0"
		doctype-public="-//W3C//DTD HTML 4.01//EN" doctype-system="http://www.w3.org/TR/html4/strict.dtd" />

	<!-- The code here is pulled from early implementations of the report. 					-->
	<!-- This WILL produce a report, but it will not be as robust and polished as Archive. -->
	<xsl:template match="optimreport:LoadReport | optimreport:loadReport">
		<!-- BEGIN SUMMARY SECTION -->
		<xsl:apply-templates select="optimreport:summary[@*]" />
		<!-- END SUMMARY SECTION -->
		
		<xsl:call-template name="anchorSetup">
			<xsl:with-param name="name">procdets</xsl:with-param>
		</xsl:call-template>
		
		<!--BEGIN TITLE BAR-->
		<xsl:call-template name="titleBar">
			<xsl:with-param name="name">Process Details</xsl:with-param>
			<xsl:with-param name="containerId">details_container</xsl:with-param>
			<xsl:with-param name="containerClass">details_container_class</xsl:with-param>
			<xsl:with-param name="anchor">procdets</xsl:with-param>
			<xsl:with-param name="closeByDefault">false</xsl:with-param>
		</xsl:call-template>

		<div id="details_container" class="section_container details_container_class" inAllAction="true">
			<table>
				<!--BEGIN TABLE MAP-->
				<xsl:apply-templates select="./optimreport:tableMap"/>
				<xsl:apply-templates select="./optimreport:localTableMap"/>
				<!--END TABLE MAP-->
				
				<!--BEGIN SOURCE FILE-->
				<xsl:apply-templates select="./optimreport:file">
					<xsl:with-param name="tableName">Source File</xsl:with-param>
				</xsl:apply-templates>
				<!--END SOURCE FILE-->

				<!--BEGIN CONTROL FILE-->
				<xsl:apply-templates select="optimreport:controlFile"/>
				<!--END CONTROL FILE-->
			</table>
			
			<xsl:call-template name="loadEntities" />
		</div>

		<xsl:if test="optimreport:dataMaskStatistics/optimreport:policyStatistics/optimreport:policyStatistic">
			<xsl:apply-templates select="optimreport:dataMaskStatistics" />
		</xsl:if>
		
		<!-- Request Options Section -->
		<xsl:if test="optimreport:requestOptions/*">
			<xsl:apply-templates select="optimreport:requestOptions">
				<xsl:with-param name="display">False</xsl:with-param>
			</xsl:apply-templates>
		</xsl:if>

		<!-- DDL Statement Section -->
		<xsl:if test="optimreport:ddlStatements/*">
			<xsl:apply-templates select="optimreport:ddlStatements" />
		</xsl:if>
		<!-- Load Message Section -->
		<xsl:apply-templates select="optimreport:loadMessage" />
	</xsl:template>
	<!--  END LoadReport section -->
	
	<!-- BEGIN entities section -->
	<xsl:template name="loadEntities">
		<table class="entity_details noBorder">
			<xsl:for-each select="optimreport:entities/optimreport:entity">
				<!-- Table Title -->
				<tr class="alternativeTitle" isTitle="yes">
					<xsl:choose>
						<xsl:when test="position() = 1 or position() mod 20 = 0">
							<xsl:attribute name="style"></xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="style">display:none</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<td>
					</td>
					<td>
						<center>
							<xsl:text>Converted</xsl:text>
						</center>
					</td>
					<td>
						<center>
							<xsl:text>Extracted</xsl:text>
						</center>
					</td>
					<td>
						<center>
							<xsl:text>Skipped</xsl:text>
						</center>
					</td>
					<td>
						<center>
							<xsl:text>Failed</xsl:text>
						</center>
					</td>
				</tr>
				<xsl:variable name="rowid">
					<xsl:value-of select="generate-id()"/>
				</xsl:variable>

				<xsl:variable name="childrenRowsId">
					<xsl:value-of select="generate-id(optimreport:maskedColumns)"/>
				</xsl:variable>
				<tr class="rightAlign" swaparrow="true">
					<th class="drop_down_hover category_title entity_rows" onClick="toggleRows('{$rowid}', event); SwapByClass('blockArrow', '{$rowid}', event); SwapChildrenElement('blockArrow', 'entity_details', '{$childrenRowsId}', '{$rowid}', event); ShowNextTitle('alternativeTitle', '{$rowid}', event);">
						<xsl:variable name="numberOfClassifiedUnmaskedColumns">
							<xsl:value-of select="count(optimreport:unmaskedColumns/optimcommon:column/optimcommon:privacyInformation/optimcommon:classification[@label and @label!=''])" />
						</xsl:variable>
						<xsl:variable name="numberOfEmptymaskedColumns">
							<xsl:value-of select="count(optimreport:maskedColumns/optimcommon:column/optimcommon:privacyInformation/optimcommon:classification[not(@label) or @label=''])" />
						</xsl:variable>
						<xsl:variable name="numberOfmaskedColumns">
							<xsl:value-of select="count(optimreport:maskedColumns/optimcommon:column)"/>
						</xsl:variable>
						<xsl:variable name="description">
							<xsl:choose>
								<xsl:when test="number($numberOfmaskedColumns)">
									<xsl:choose>
										<xsl:when test="(number($numberOfClassifiedUnmaskedColumns) + number($numberOfEmptymaskedColumns)) &lt; 2">
											<xsl:text>Data in this table was masked according to the specified privacy policy of one or more columns, and one of the columns in this table has warning message.</xsl:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:text>Data in this table was masked according to the specified privacy policy of one or more columns, and </xsl:text>
											<xsl:value-of select="$numberOfClassifiedUnmaskedColumns + $numberOfEmptymaskedColumns"/>
											<xsl:text> of the columns in this table has warning messages.</xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:when>
								<xsl:otherwise>
									<xsl:choose>
										<xsl:when test="(number($numberOfClassifiedUnmaskedColumns) + number($numberOfEmptymaskedColumns)) &lt; 2">
											<xsl:text>One of the columns in this table has warning message.</xsl:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="$numberOfClassifiedUnmaskedColumns + $numberOfEmptymaskedColumns"/>
											<xsl:text> of the columns in this table has warning messages.</xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>

						<xsl:choose>
							<xsl:when test="(number($numberOfClassifiedUnmaskedColumns) + number($numberOfEmptymaskedColumns))">
								<xsl:call-template name="setImage">
									<xsl:with-param name="class">infopop_warning_class</xsl:with-param>
									<xsl:with-param name="name">warning</xsl:with-param>
									<xsl:with-param name="URI">
										<xsl:choose>
											<xsl:when test="number($numberOfmaskedColumns)">
												<xsl:value-of select="$ribbonWarning_URI"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="$warning_URI"/>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:with-param>
									<xsl:with-param name="description" select="$description"/>
								</xsl:call-template>

								<xsl:call-template name="popupBlock">
									<xsl:with-param name="class">warning_pop_class</xsl:with-param>
									<xsl:with-param name="description" select="$description"/>
								</xsl:call-template>
							</xsl:when>
							<!-- If has masked columns and no warnings-->
							<xsl:when test="number($numberOfmaskedColumns)">
								<xsl:call-template name="setImage">
									<xsl:with-param name="class">infopop_warning_class</xsl:with-param>
									<xsl:with-param name="name">warning</xsl:with-param>
									<xsl:with-param name="URI">
										<xsl:value-of select="$medal_URI"/>
									</xsl:with-param>
									<xsl:with-param name="description" select="$medalDescription"/>
								</xsl:call-template>

								<xsl:call-template name="popupBlock">
									<xsl:with-param name="class">infopop_warning_class</xsl:with-param>
									<xsl:with-param name="description" select="$medalDescription"/>
								</xsl:call-template>
							</xsl:when>
						</xsl:choose>

						<!--Table name-->
						<xsl:call-template name="arrow">
							<xsl:with-param name="id" select="concat($rowid,'_arrow')"/>
							<xsl:with-param name="isExpand">false</xsl:with-param>
						</xsl:call-template>
						<span class="main_title">
							<xsl:call-template name="stringCheck">
								<xsl:with-param name="value" select="@name"/>
							</xsl:call-template>
						</span>
					</th>
					<td align="right">
						<xsl:choose>
							<xsl:when test='number(@converted) = number(@converted)'>
								<xsl:call-template name="numberFormat">
									<xsl:with-param name="number" select="@converted"/>
									<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:call-template name='stringCheck'>
									<xsl:with-param name='value' select='@converted'/>
								</xsl:call-template>
							</xsl:otherwise>
						</xsl:choose>
					</td>
					<td align="right">
						<xsl:choose>
							<xsl:when test='number(@extracted) = number(@extracted)'>
								<xsl:call-template name="numberFormat">
									<xsl:with-param name="number" select="@extracted"/>
									<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:call-template name='stringCheck'>
									<xsl:with-param name='value' select='@extracted'/>
								</xsl:call-template>
							</xsl:otherwise>
						</xsl:choose>
					</td>
					<td align="right">
						<xsl:choose>
							<xsl:when test='number(@skipped) = number(@skipped)'>
								<xsl:call-template name="numberFormat">
									<xsl:with-param name="number" select="@skipped"/>
									<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:call-template name='stringCheck'>
									<xsl:with-param name='value' select='@skipped'/>
								</xsl:call-template>
							</xsl:otherwise>
						</xsl:choose>
					</td>
					<td align="right">
						<xsl:choose>
							<xsl:when test='number(@failed) = number(@failed)'>
								<xsl:call-template name="numberFormat">
									<xsl:with-param name="number" select="@failed"/>
									<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:call-template name='stringCheck'>
									<xsl:with-param name='value' select='@failed'/>
								</xsl:call-template>
							</xsl:otherwise>
						</xsl:choose>
					</td>
				</tr>
				
				<!-- Column Information -->
				<xsl:call-template name="columnMap">
					<xsl:with-param name="rowid" select="$rowid"/>
					<xsl:with-param name="childrenRowsId" select="$childrenRowsId"/>
					<xsl:with-param name="warning_URI" select="$warning_URI"/>
					<xsl:with-param name="information_URI" select="$information_URI"/>
				</xsl:call-template>

				<xsl:if test="not(position() = last())">
					<tr class="hiddenRow">
						<td colspan="4"></td>
					</tr>
				</xsl:if>
			</xsl:for-each>
		</table>
	</xsl:template>
	<!-- END entities section -->
	
	
</xsl:stylesheet>

